===========================
 Contributor Documentation
===========================

In this section you will find information on how to contribute to
skyline-console. Content includes architectural overviews, tips and tricks
for setting up a development environment.

Getting Started
---------------
.. toctree::
    :maxdepth: 2

    contributing
    backporting
    releases
    documentation

Writing Release Notes
---------------------

Please follow the format, it will make everyone's life easier.

.. toctree::
    :maxdepth: 2

    releasenotes

.. _programming-howtos:

Programming HowTos and Tutorials
--------------------------------

.. toctree::
    :maxdepth: 2

    development.environment

Other Resources
---------------
.. toctree::
   :maxdepth: 3

   gerrit
   releasenotes

.. only:: html

   Indices and tables
   ------------------

   * :ref:`genindex`
   * :ref:`search`
